event library

Event models for OBS WebSocket protocol notifications.

This library exports all event classes that OBS Studio can broadcast to connected WebSocket clients. Events cover canvases, configuration changes, general system events, inputs, filters, media, outputs, scenes, scene items, transitions, and UI state changes.

Classes

BaseCanvasEvent
Base class for all canvas-related events.
BaseSceneEvent
Base class for all scene-related events.
BaseSceneGroupEvent
Base class for scene group events.
CanvasCreated
A canvas has been created.
CanvasNameChanged
The name of a canvas has changed.
CanvasRemoved
A canvas has been removed.
CurrentPreviewSceneChanged
The current preview scene has changed.
CurrentProfileChanged
The current profile has changed.
CurrentProfileChanging
The current profile has begun changing.
CurrentProgramSceneChanged
The current program scene has changed.
CurrentSceneCollectionChanged
The current scene collection has changed.
CurrentSceneCollectionChanging
The current scene collection has begun changing.
CurrentSceneTransitionChanged
The current scene transition has changed.
CurrentSceneTransitionDurationChanged
The current scene transition duration has changed.
CustomEvent
Custom event emitted by BroadcastCustomEvent.
ExitStarted
InputActiveStateChanged
An input's active state has changed.
InputAudioBalanceChanged
The audio balance value of an input has changed.
InputAudioMonitorTypeChanged
The monitor type of an input has changed.
InputAudioSyncOffsetChanged
The sync offset of an input has changed.
InputAudioTracksChanged
The audio tracks of an input have changed.
InputCreated
An input has been created.
InputMuteStateChanged
An input's mute state has changed.
InputNameChanged
The name of an input has changed.
InputRemoved
An input has been removed.
InputSettingsChanged
An input's settings have changed (been updated).
InputShowStateChanged
An input's show state has changed.
InputVolumeChanged
An input's volume level has changed.
InputVolumeMeters
A high-volume event providing volume levels of all active inputs every 50 milliseconds.
MediaInputActionTriggered
An action has been performed on an input.
MediaInputPlaybackEnded
A media input has finished playing.
MediaInputPlaybackStarted
A media input has started playing.
ProfileListChanged
The scene collection list has changed.
RecordFileChanged
The record output has started writing to a new file.
RecordStateChanged
The state of the record output has changed.
ReplayBufferSaved
Path of the saved replay file
ReplayBufferStateChanged
The state of the replay buffer output has changed.
SceneCollectionListChanged
The scene collection list has changed.
SceneCreated
A new scene has been created.
SceneItemCreated
A scene item's enable state has changed.
SceneItemEnableStateChanged
A scene item's enable state has changed.
SceneItemListReindexed
A scene's item list has been reindexed.
SceneItemLockStateChanged
A scene item's lock state has changed.
SceneItemRemoved
This event is not emitted when the scene the item is in is removed.
SceneItemSelected
A scene item has been selected in the Ui.
SceneItemTransformChanged
The transform/crop of a scene item has changed.
SceneListChanged
The list of scenes has changed.
SceneNameChanged
The name of a scene has changed.
SceneRemoved
A scene has been removed.
SceneTransitionEnded
A scene transition has completed fully.
SceneTransitionStarted
A scene transition has started.
SceneTransitionVideoEnded
A scene transition's video has completed fully.
ScreenshotSaved
A screenshot has been saved.
SourceFilterCreated
A filter has been added to a source.
SourceFilterEnableStateChanged
A source filter's enable state has changed.
SourceFilterListReindexed
A source's filter list has been reindexed.
SourceFilterNameChanged
The name of a source filter has changed.
SourceFilterRemoved
A filter has been removed from a source.
SourceFilterSettingsChanged
A source filter's settings have changed.
StreamStateChanged
The state of the stream output has changed.
StudioModeStateChanged
Studio mode has been enabled or disabled.
VendorEvent
VirtualcamStateChanged
The state of the replay buffer output has changed.