BaseCanvasEvent class

Base class for all canvas-related events.

This event is triggered when canvas operations occur, such as creation, removal, or name changes. Introduced in OBS WebSocket v5.7.0.

Implementers
Annotations
  • @JsonSerializable.new()

Constructors

BaseCanvasEvent({required String canvasName, required String canvasUuid})
Creates a new canvas event with the specified name and UUID.
BaseCanvasEvent.fromJson(Map<String, dynamic> json)
Creates a canvas event from a JSON map.
factory

Properties

canvasName String
Name of the canvas
final
canvasUuid String
UUID of the canvas
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the event to a JSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited