BaseSceneGroupEvent class

Base class for scene group events.

Extends BaseSceneEvent to include information about whether the scene is a group (a collection of sources grouped together).

Inheritance
Implementers
Annotations
  • @JsonSerializable.new()

Constructors

BaseSceneGroupEvent({required String sceneName, required String sceneUuid, required bool isGroup})
Creates a new scene group event.
BaseSceneGroupEvent.fromJson(Map<String, dynamic> json)
Creates a scene group event from a JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isGroup bool
Whether the new scene is a group
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sceneName String
Name of the new scene
finalinherited
sceneUuid String
UUID of the new scene
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the event to a JSON map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited