CanvasNameChanged class

The name of a canvas has changed.

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

CanvasNameChanged({required String canvasName, required String canvasUuid, required String oldCanvasName})
CanvasNameChanged.fromJson(Map<String, dynamic> json)
factory

Properties

canvasName String
Name of the canvas
finalinherited
canvasUuid String
UUID of the canvas
finalinherited
hashCode int
The hash code for this object.
no setterinherited
oldCanvasName String
Old name of the canvas
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the event to a JSON map.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited