CurrentSceneTransitionChanged class

The current scene transition has changed.

Annotations
  • @JsonSerializable.new()

Constructors

CurrentSceneTransitionChanged({required String transitionName, String? transitionUuid})
Creates an event for when the current scene transition changes.
CurrentSceneTransitionChanged.fromJson(Map<String, dynamic> json)
Creates an event from a JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transitionName String
Name of the new transition
final
transitionUuid String?
UUID of the new transition
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the event to a JSON map.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited