InputMuteStateChanged class

An input's mute state has changed.

Complexity Rating: 2/5 Latest Supported RPC Version: 1 Added in v5.0.0

Annotations
  • @JsonSerializable.new()

Constructors

InputMuteStateChanged({required String inputName, required String inputUuid, required bool inputMuted})
Creates an event for when an input's mute state changes.
InputMuteStateChanged.fromJson(Map<String, dynamic> json)
Creates an event from a JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
inputMuted bool
Whether the input is muted
final
inputName String
Name of the input
final
inputUuid String
UUID of the input
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the event to a JSON map.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited