MediaInputActionTriggered class

An action has been performed on an input.

Annotations
  • @JsonSerializable.new()

Constructors

MediaInputActionTriggered({required String inputName, String? inputUuid, required String mediaAction})
MediaInputActionTriggered.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
inputName String
Name of the input
final
inputUuid String?
UUID of the input
final
mediaAction String
Action performed on the input. See ObsMediaInputAction enum
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the event to a JSON map.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited