RecordFileChanged class

The record output has started writing to a new file.

For example, file splitting or manual chapter creation.

Added in v5.5.0

Annotations
  • @JsonSerializable.new()

Constructors

RecordFileChanged({required String newOutputPath})
RecordFileChanged.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
newOutputPath String
File name that the output has begun writing to
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the event to a JSON map.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited