RecordStateChanged class

The state of the record output has changed.

Annotations
  • @JsonSerializable.new()

Constructors

RecordStateChanged({required bool outputActive, required String outputState, required String outputPath})
Creates an event for when the record state changes.
RecordStateChanged.fromJson(Map<String, dynamic> json)
Creates an event from a JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
outputActive bool
Whether the output is active
final
outputPath String
File name for the saved recording, if record stopped. null otherwise
final
outputState String
The specific state of the output
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the event to a JSON map.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited