SceneItemListReindexed class

A scene's item list has been reindexed.

Annotations
  • @JsonSerializable.new()

Constructors

SceneItemListReindexed({required String sceneName, required List<Map<String, dynamic>> sceneItems})
SceneItemListReindexed.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sceneItems List<Map<String, dynamic>>
Array of scene item objects (with sceneItemId and sceneItemIndex)
final
sceneName String
Name of the scene
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the event to a JSON map.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited