SceneItemLockStateChanged class

A scene item's lock state has changed.

Annotations
  • @JsonSerializable.new()

Constructors

SceneItemLockStateChanged({required String sceneName, required int sceneItemId, required bool sceneItemLocked})
Creates an event for when a scene item's lock state changes.
SceneItemLockStateChanged.fromJson(Map<String, dynamic> json)
Creates an event from a JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sceneItemId int
Numeric ID of the scene item
final
sceneItemLocked bool
Whether the scene item is locked
final
sceneName String
Name of the scene the item is in
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the event to a JSON map.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited