SourceFilterEnableStateChanged class

A source filter's enable state has changed.

Annotations
  • @JsonSerializable.new()

Constructors

SourceFilterEnableStateChanged({required String sourceName, required String filterName, required bool filterEnabled})
Creates an event for when a source filter's enabled state changes.
SourceFilterEnableStateChanged.fromJson(Map<String, dynamic> json)
Creates an event from a JSON map.
factory

Properties

filterEnabled bool
Whether the filter is enabled
final
filterName String
Name of the filter
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceName String
Name of the source the filter is on
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the event to a JSON map.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited