SourceFilterListReindexed class
A source's filter list has been reindexed.
- Annotations
-
- @JsonSerializable.new()
Constructors
-
SourceFilterListReindexed({required String sourceName, required List<
Map< filters})String, dynamic> > -
SourceFilterListReindexed.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
filters
→ List<
Map< String, dynamic> > -
Array of filter objects (with filterName and filterIndex)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceName → String
-
Name of the source
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts the event to a JSON map.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited