SourceFilterNameChanged class
The name of a source filter has changed.
- Annotations
-
- @JsonSerializable.new()
Constructors
- SourceFilterNameChanged({required String sourceName, required String oldFilterName, required String filterName})
-
SourceFilterNameChanged.fromJson(Map<
String, dynamic> json) -
factory
Properties
- filterName → String
-
New name of the filter
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- oldFilterName → String
-
Old name of the filter
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceName → String
-
Name of the source the filter is on
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts the event to a JSON map.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited