SourceFilterRemoved class
A filter has been removed from a source.
- Annotations
-
- @JsonSerializable.new()
Constructors
- SourceFilterRemoved({required String sourceName, required String filterName})
-
SourceFilterRemoved.fromJson(Map<
String, dynamic> json) -
factory
Properties
- filterName → String
-
Name of the filter
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceName → String
-
Name of the source the filter was removed from
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts the event to a JSON map.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited