ObsDeinterlaceFieldOrder enum
Deinterlace field order for an input
Values
- top → const ObsDeinterlaceFieldOrder
-
const ObsDeinterlaceFieldOrder('OBS_DEINTERLACE_FIELD_ORDER_TOP') - bottom → const ObsDeinterlaceFieldOrder
-
const ObsDeinterlaceFieldOrder('OBS_DEINTERLACE_FIELD_ORDER_BOTTOM')
Properties
- code → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromCode(
String code) → ObsDeinterlaceFieldOrder - Returns the enum value from its string code
Constants
-
values
→ const List<
ObsDeinterlaceFieldOrder> - A constant List of the values in this enum, in order of their declaration.