Filters class

Filters Requests

Constructors

Filters(ObsWebSocket obsWebSocket)

Properties

hashCode int
The hash code for this object.
no setterinherited
obsWebSocket ObsWebSocket
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createSourceFilter({required String sourceName, required String filterName, required String filterKind, Map<String, dynamic>? filterSettings}) Future<void>
Creates a new filter, adding it to the specified source.
getSourceFilter({required String sourceName, required String filterName}) Future<Map<String, dynamic>>
Gets the info for a specific source filter.
getSourceFilterDefaultSettings(String filterKind) Future<Map<String, dynamic>>
Gets the default settings for a filter kind.
getSourceFilterKindList() Future<List<String>>
Gets an array of all available source filter kinds.
getSourceFilterList(String sourceName) Future<List<Map<String, dynamic>>>
Gets an array of all of a source's filters.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeSource({required String sourceName, required String filterName}) Future<void>
Removes a filter from a source.
removeSourceFilter({required String sourceName, required String filterName}) Future<void>
Removes a filter from a source.
setSourceEnabled({required String sourceName, required String filterName, required bool filterEnabled}) Future<void>
Sets the enable state of a source filter.
setSourceFilterEnabled({required String sourceName, required String filterName, required bool filterEnabled}) Future<void>
Sets the enable state of a source filter.
setSourceFilterIndex({required String sourceName, required String filterName, required int filterIndex}) Future<void>
Sets the index position of a filter on a source.
setSourceFilterName({required String sourceName, required String filterName, required String newFilterName}) Future<void>
Sets the name of a source filter (rename).
setSourceFilterSettings({required String sourceName, required String filterName, required Map<String, dynamic> filterSettings, bool? overlay}) Future<void>
Sets the settings of a source filter.
setSourceIndex({required String sourceName, required String filterName, required int filterIndex}) Future<void>
Sets the index position of a filter on a source.
setSourceName({required String sourceName, required String filterName, required String newFilterName}) Future<void>
Sets the name of a source filter (rename).
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited