Inputs class

Inputs Requests

Constructors

Inputs(ObsWebSocket obsWebSocket)

Properties

hashCode int
The hash code for this object.
no setterinherited
obsWebSocket ObsWebSocket
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create({String? sceneName, String? sceneUuid, required String inputName, required String inputKind, dynamic inputSettings, bool? sceneItemEnabled}) Future<CreateInputResponse>
Creates a new input, adding it as a scene item to the specified scene.
createInput({String? sceneName, String? sceneUuid, required String inputName, required String inputKind, Map<String, dynamic>? inputSettings, bool? sceneItemEnabled}) Future<CreateInputResponse>
Creates a new input, adding it as a scene item to the specified scene.
defaultSettings({required String inputKind}) Future<InputDefaultSettingsResponse>
Gets the default settings for an input kind.
getInputAudioBalance({String? inputName, String? inputUuid}) Future<InputAudioBalanceResponse>
Gets the audio balance of an input.
getInputAudioMonitorType({String? inputName, String? inputUuid}) Future<InputAudioMonitorTypeResponse>
Gets the audio monitor type of an input.
getInputAudioSyncOffset({String? inputName, String? inputUuid}) Future<InputAudioSyncOffsetResponse>
Gets the audio sync offset of an input.
getInputAudioTracks({String? inputName, String? inputUuid}) Future<InputAudioTracksResponse>
Gets the audio tracks of an input.
getInputDefaultSettings({required String inputKind}) Future<InputDefaultSettingsResponse>
Gets the default settings for an input kind.
getInputDeinterlaceFieldOrder({String? inputName, String? inputUuid}) Future<InputDeinterlaceFieldOrderResponse>
Gets the deinterlace field order of an input.
getInputDeinterlaceMode({String? inputName, String? inputUuid}) Future<InputDeinterlaceModeResponse>
Gets the deinterlace mode of an input.
getInputKindList([bool unversioned = false]) Future<List<String>>
Gets an array of all available input kinds in OBS.
getInputList(String? inputKind) Future<List<Input>>
Gets an array of all inputs in OBS.
getInputMute(String inputName) Future<bool>
Gets the audio mute state of an input.
getInputPropertiesListPropertyItems({String? inputName, String? inputUuid, required String propertyName}) Future<InputPropertiesListPropertyItemsResponse>
Gets the items of a list property from an input's properties.
getInputSettings({String? inputName, String? inputUuid}) Future<InputSettingsResponse>
Gets the settings of an input.
getInputVolume({String? inputName, String? inputUuid}) Future<InputVolumeResponse>
Gets the current volume setting of an input.
getMute(String inputName) Future<bool>
Gets the audio mute state of an input.
getSpecialInputs() Future<SpecialInputsResponse>
Gets the names of all special inputs.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pressInputPropertiesButton({String? inputName, String? inputUuid, required String propertyName}) Future<void>
Presses a button in the input's properties.
remove({String? inputName, String? inputUuid}) Future<void>
Removes an existing input.
removeInput({String? inputName, String? inputUuid}) Future<void>
Removes an existing input.
setInputAudioBalance({String? inputName, String? inputUuid, required double inputAudioBalance}) Future<void>
Sets the audio balance of an input.
setInputAudioMonitorType({String? inputName, String? inputUuid, required ObsMonitoringType monitorType}) Future<void>
Sets the audio monitor type of an input.
setInputAudioSyncOffset({String? inputName, String? inputUuid, required int inputAudioSyncOffset}) Future<void>
Sets the audio sync offset of an input.
setInputAudioTracks({String? inputName, String? inputUuid, required int inputAudioTracks}) Future<void>
Sets the audio tracks of an input.
setInputDeinterlaceFieldOrder({String? inputName, String? inputUuid, required ObsDeinterlaceFieldOrder deinterlaceFieldOrder}) Future<void>
Sets the deinterlace field order of an input.
setInputDeinterlaceMode({String? inputName, String? inputUuid, required ObsDeinterlaceMode deinterlaceMode}) Future<void>
Sets the deinterlace mode of an input.
setInputMute({String? inputName, String? inputUuid, required bool inputMuted}) Future<void>
Sets the audio mute state of an input.
setInputName({String? inputName, String? inputUuid, required String newInputName}) Future<void>
Sets the name of an input (rename).
setInputSettings({String? inputName, String? inputUuid, required Map<String, dynamic> inputSettings, bool? overlay}) Future<void>
Sets the settings of an input.
setInputVolume({String? inputName, String? inputUuid, required double inputVolume}) Future<void>
Sets the volume of an input.
setMute({String? inputName, String? inputUuid, required bool inputMuted}) Future<void>
Sets the audio mute state of an input.
setName({String? inputName, String? inputUuid, required String newInputName}) Future<void>
Sets the name of an input (rename).
setSettings({String? inputName, String? inputUuid, required Map<String, dynamic> inputSettings, bool? overlay}) Future<void>
Sets the settings of an input.
settings({String? inputName, String? inputUuid}) Future<InputSettingsResponse>
Gets the settings of an input.
specialInputs() Future<SpecialInputsResponse>
Gets the names of all special inputs.
toggleInputMute({String? inputName, String? inputUuid}) Future<bool>
Toggles the audio mute state of an input.
toggleMute({String? inputName, String? inputUuid}) Future<bool>
Toggles the audio mute state of an input.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited