createRecordChapter method

Future<void> createRecordChapter({
  1. String? chapterName,
})

Adds a new chapter marker to the file currently being recorded.

Note: As of OBS 30.2.0, the only file format supporting this feature is Hybrid MP4.

  • Complexity Rating: 1/5
  • Latest Supported RPC Version: 1
  • Added in v5.5.0

Implementation

Future<void> createRecordChapter({String? chapterName}) async =>
    await obsWebSocket.sendRequest(
      Request(
        'CreateRecordChapter',
        requestData: chapterName == null
            ? null
            : {'chapterName': chapterName},
      ),
    );