SceneItems class

Record Requests

Constructors

SceneItems(ObsWebSocket obsWebSocket)

Properties

hashCode int
The hash code for this object.
no setterinherited
obsWebSocket ObsWebSocket
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createSceneItem({required String sceneName, required String sourceName, bool? sceneItemEnabled}) Future<int>
Creates a new scene item using a source.
duplicateSceneItem({required String sceneName, required int sceneItemId, String? destinationSceneName}) Future<int>
Duplicates a scene item, copying all transform and crop info.
getEnabled({required String sceneName, required int sceneItemId}) Future<bool>
Gets the enable state of a scene item.
getGroupSceneItemList(String sceneName) Future<List<SceneItemDetail>>
Basically GetSceneItemList, but for groups.
getId({required String sceneName, required String sourceName, int? searchOffset}) Future<int>
Searches a scene for a source, and returns its id.
getIndex({required String sceneName, required int sceneItemId}) Future<int>
Gets the index position of a scene item in a scene.
getLocked({required String sceneName, required int sceneItemId}) Future<bool>
Gets the lock state of a scene item.
getSceneItemBlendMode({required String sceneName, required int sceneItemId}) Future<String>
Gets the blend mode of a scene item.
getSceneItemEnabled({required String sceneName, required int sceneItemId}) Future<bool>
Gets the enable state of a scene item.
getSceneItemId({required String sceneName, required String sourceName, int? searchOffset}) Future<int>
Searches a scene for a source, and returns its id.
getSceneItemIndex({required String sceneName, required int sceneItemId}) Future<int>
Gets the index position of a scene item in a scene.
getSceneItemList(String sceneName) Future<List<SceneItemDetail>>
Gets a list of all scene items in a scene.
getSceneItemLocked({required String sceneName, required int sceneItemId}) Future<bool>
Gets the lock state of a scene item.
getSceneItemPrivateSettings({String? sceneName, String? sceneUuid, required int sceneItemId}) Future<Map<String, dynamic>>
Gets the private settings of a scene item.
getSceneItemSource({String? sceneName, String? sceneUuid, required int sceneItemId}) Future<Map<String, dynamic>>
Gets the source associated with a scene item.
getSceneItemTransform({required String sceneName, required int sceneItemId}) Future<Map<String, dynamic>>
Gets the transform (position, scale, rotation, crop) of a scene item.
groupList(String sceneName) Future<List<SceneItemDetail>>
Basically GetSceneItemList, but for groups.
list(String sceneName) Future<List<SceneItemDetail>>
Gets a list of all scene items in a scene.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeSceneItem({required String sceneName, required int sceneItemId}) Future<void>
Removes a scene item from a scene.
setEnabled(SceneItemEnableStateChanged sceneItemEnableStateChanged) Future<void>
Sets the enable state of a scene item.
setIndex({required String sceneName, required int sceneItemId, required int sceneItemIndex}) Future<void>
Sets the index position of a scene item in a scene.
setLocked({required String sceneName, required int sceneItemId, required bool sceneItemLocked}) Future<void>
Sets the lock state of a scene item.
setSceneItemBlendMode({required String sceneName, required int sceneItemId, required String sceneItemBlendMode}) Future<void>
Sets the blend mode of a scene item.
setSceneItemEnabled(SceneItemEnableStateChanged sceneItemEnableStateChanged) Future<void>
Sets the enable state of a scene item.
setSceneItemIndex({required String sceneName, required int sceneItemId, required int sceneItemIndex}) Future<void>
Sets the index position of a scene item in a scene.
setSceneItemLocked({required String sceneName, required int sceneItemId, required bool sceneItemLocked}) Future<void>
Sets the lock state of a scene item.
setSceneItemPrivateSettings({String? sceneName, String? sceneUuid, required int sceneItemId, required Map<String, dynamic> sceneItemSettings}) Future<void>
Sets the private settings of a scene item.
setSceneItemTransform({required String sceneName, required int sceneItemId, required Map<String, dynamic> sceneItemTransform}) Future<void>
Sets the transform (position, scale, rotation, crop) of a scene item.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited