CanvasCreated class
A canvas has been created.
- Inheritance
-
- Object
- BaseCanvasEvent
- CanvasCreated
- Annotations
-
- @JsonSerializable.new()
Constructors
- CanvasCreated({required String canvasName, required String canvasUuid})
-
CanvasCreated.fromJson(Map<
String, dynamic> json) -
factory
Properties
- canvasName → String
-
Name of the canvas
finalinherited
- canvasUuid → String
-
UUID of the canvas
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts the event to a JSON map.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited