CurrentSceneTransitionDurationChanged class
The current scene transition duration has changed.
- Annotations
-
- @JsonSerializable.new()
Constructors
- CurrentSceneTransitionDurationChanged({required int transitionDuration})
-
CurrentSceneTransitionDurationChanged.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transitionDuration → int
-
Transition duration in milliseconds
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts the event to a JSON map.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited