SceneTransitionVideoEnded class
A scene transition's video has completed fully.
Useful for stinger transitions to tell when the video actually ends.
SceneTransitionEnded only signifies the cut point, not the end of the
transition playback.
Note: Appears to be called by every transition, regardless of relevance.
- Annotations
-
- @JsonSerializable.new()
Constructors
- SceneTransitionVideoEnded({required String transitionName, String? transitionUuid})
-
SceneTransitionVideoEnded.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transitionName → String
-
Scene transition name
final
- transitionUuid → String?
-
Scene transition UUID
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts the event to a JSON map.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited