SourceFilterCreated class
A filter has been added to a source.
- Annotations
-
- @JsonSerializable.new()
Constructors
Properties
-
defaultFilterSettings
→ Map<
String, dynamic> -
The default settings for the filter
final
- filterIndex → int
-
Index position of the filter
final
- filterKind → String
-
The kind of the filter
final
- filterName → String
-
Name of the filter
final
-
filterSettings
→ Map<
String, dynamic> -
The settings configured to the filter when it was created
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceName → String
-
Name of the source the filter was added to
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts the event to a JSON map.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited