ObsDeinterlaceMode enum
Deinterlace mode for an input
Values
- disable → const ObsDeinterlaceMode
-
const ObsDeinterlaceMode('OBS_DEINTERLACE_MODE_DISABLE') - discard → const ObsDeinterlaceMode
-
const ObsDeinterlaceMode('OBS_DEINTERLACE_MODE_DISCARD') - retro → const ObsDeinterlaceMode
-
const ObsDeinterlaceMode('OBS_DEINTERLACE_MODE_RETRO') - blend → const ObsDeinterlaceMode
-
const ObsDeinterlaceMode('OBS_DEINTERLACE_MODE_BLEND') - blend2x → const ObsDeinterlaceMode
-
const ObsDeinterlaceMode('OBS_DEINTERLACE_MODE_BLEND_2X') - linear → const ObsDeinterlaceMode
-
const ObsDeinterlaceMode('OBS_DEINTERLACE_MODE_LINEAR') - linear2x → const ObsDeinterlaceMode
-
const ObsDeinterlaceMode('OBS_DEINTERLACE_MODE_LINEAR_2X') - yadif → const ObsDeinterlaceMode
-
const ObsDeinterlaceMode('OBS_DEINTERLACE_MODE_YADIF') - yadif2x → const ObsDeinterlaceMode
-
const ObsDeinterlaceMode('OBS_WEBSOCKET_DEINTERLACE_MODE_YADIF_2X')
Properties
- code → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromCode(
String code) → ObsDeinterlaceMode - Returns the enum value from its string code
Constants
-
values
→ const List<
ObsDeinterlaceMode> - A constant List of the values in this enum, in order of their declaration.