ObsRequestException class final
An OBS Request returned a non-success RequestStatus.
code is the OBS WebSocket status code and comment is the server-supplied explanation, when present.
- Inheritance
-
- Object
- ObsException
- ObsRequestException
Constructors
- ObsRequestException({required String requestType, required int code, String? comment, StackTrace? stackTrace})
Properties
- cause → Object?
-
Original error that triggered this exception, if any.
finalinherited
- code → int
-
final
- comment → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable description of the error.
finalinherited
- requestType → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
Stack trace captured at the throw site, when available.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited