PropertyItem class
A single property item in a list
- Annotations
-
- @JsonSerializable.new()
Constructors
- PropertyItem({required String itemValue, required String itemText, required bool itemEnabled})
-
PropertyItem.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemEnabled → bool
-
Whether the item is enabled
final
- itemText → String
-
Human-readable item text
final
- itemValue → String
-
Unique item value
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited