Sources class
Sources Requests
Constructors
- Sources(ObsWebSocket obsWebSocket)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- obsWebSocket → ObsWebSocket
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
active(
String sourceName) → Future< SourceActiveResponse> - Gets the active and show state of a source.
-
getSourceActive(
String sourceName) → Future< SourceActiveResponse> - Gets the active and show state of a source.
-
getSourcePrivateSettings(
{String? sourceName, String? sourceUuid}) → Future< Map< String, dynamic> > - Gets the private settings of a source. This request is mainly just used in interacting with global sources (e.g. Global Audio Devices).
-
getSourceScreenshot(
SourceScreenshot sourceScreenshot) → Future< SourceScreenshotResponse> - Gets a Base64-encoded screenshot of a source.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
saveScreenshot(
SourceScreenshot sourceScreenshot) → Future< SourceScreenshotResponse> - Saves a screenshot of a source to the filesystem.
-
saveSourceScreenshot(
SourceScreenshot sourceScreenshot) → Future< SourceScreenshotResponse> - Saves a screenshot of a source to the filesystem.
-
screenshot(
SourceScreenshot sourceScreenshot) → Future< SourceScreenshotResponse> - Gets a Base64-encoded screenshot of a source.
-
setSourcePrivateSettings(
{String? sourceName, String? sourceUuid, required Map< String, dynamic> sourceSettings}) → Future<void> - Sets the private settings of a source. This request is mainly just used in interacting with global sources (e.g. Global Audio Devices).
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited