Transitions class
Transitions Requests
Constructors
- Transitions(ObsWebSocket obsWebSocket)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- obsWebSocket → ObsWebSocket
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getCurrentSceneTransition(
) → Future< Map< String, dynamic> > - Gets information about the current scene transition.
-
getCurrentSceneTransitionCursor(
) → Future< double> - Gets the cursor position of the current scene transition.
-
getSceneTransitionList(
) → Future< Map< String, dynamic> > - Gets an array of all scene transitions in OBS.
-
getTransitionKindList(
) → Future< List< String> > - Gets an array of all available transition kinds.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setCurrentScene(
String transitionName) → Future< void> - Sets the current scene transition.
-
setCurrentSceneDuration(
int transitionDuration) → Future< void> - Sets the duration of the current scene transition, if it is not fixed.
-
setCurrentSceneTransition(
String transitionName) → Future< void> - Sets the current scene transition.
-
setCurrentSceneTransitionDuration(
int transitionDuration) → Future< void> - Sets the duration of the current scene transition, if it is not fixed.
-
setCurrentSceneTransitionSettings(
{required Map< String, dynamic> transitionSettings, bool? overlay}) → Future<void> - Sets the settings of the current scene transition.
-
setTBarPosition(
{required double position, bool? release}) → Future< void> - Sets the position of the T-Bar (Transition bar).
-
toString(
) → String -
A string representation of this object.
inherited
-
triggerStudioMode(
) → Future< void> - Triggers the current scene transition. Same functionality as the Transition button in studio mode.
-
triggerStudioModeTransition(
) → Future< void> - Triggers the current scene transition. Same functionality as the Transition button in studio mode.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited